/* misc.h -- miscellaneous functions
   Copyright (C) 2004 Julio A. Becerra

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef MISC_H
#define MISC_H

#include <unistd.h>
#include <wchar.h>
#include "common.h"

#define ERR_C (ERR_LOCAL -1)
#define ERR_SIZE (ERR_LOCAL -2)
#define ERR_TAG (ERR_LOCAL -3)
#define ERR_FMT (ERR_LOCAL -4)
#define ERR_CO (ERR_LOCAL -5)

extern char *home_path (char *file);
extern char *home_path2 (char *dir, char *file);
extern int read_tag (int fd, char *src, char *name, char *buff, size_t size);
extern int write_tag (int fd, char *name, char *buff, size_t tabs);
extern int check_dir (char *dirname);
extern char *ipv4_to_string (ip_t ip);
int utf8_encode (const char *src, size_t mlen, char *utf8s, size_t utf8smlen);
char * utf8_wencode (const wchar_t *src);
int utf8_decode (const char *src, size_t mlen, char *dest, size_t destmlen);
wchar_t * utf8_wdecode (const char *src);
int get_encoding (void);

#endif
